# spbessax

This repository contains a JAX implementation of spherical bessel functions that
is fully compatible with jax.jit and jax.grad. It is based on the implementation
by @sousaw in [NeuralIL](https://github.com/Madsen-s-research-group/neuralil-public-releases).

The package can be installed from [PyPi](https://pypi.org/project/spbessax/) using pip:

`pip install psbessax`
